IDKitTapDetails class

Single point gesture

Inheritance

Constructors

IDKitTapDetails({double pressure = 0, PointerDeviceKind? kind, Offset globalPosition = Offset.zero, Offset localPosition = Offset.zero, int count = 1})
IDKitTapDetails.pressure(double pressure, SerialTapUpDetails details)
Easy to build
factory

Properties

count int
The number of consecutive taps that this tap represents.
finalinherited
globalPosition Offset
The global position at which the pointer interacts with the screen.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
kind PointerDeviceKind?
The kind of the device that initiated the event.
finalinherited
localPosition Offset
The local position in the coordinate system of the event receiver at which the pointer interacts with the screen.
finalinherited
pressure double
Finger pressure on the screen.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited